.. :changelog:

History
=======

0.2.0 (2014-12-11)
------------------
* Add ``update_only`` option to `cache.update_instance`, to support eventual
  consistency for cold caches.

0.1.0 (2014-11-06)
------------------

* First release on PyPI.
